@@ -12,6 +12,10 @@
 	2014.01.30 V00.07 Added ProductID & Vendor ID set routine
 	2014.01.31 V00.08 Bug fixed for login logic. 
 		(When callsign or password is wrong, dv_echo was looped.)
+	2014.02.03 V00.09 Added CallCheck
+	2014.02.04 V00.10 Bug fixed CallCheck
+	2014.02.04 V00.11 Added  ReloadCallCheckACL
+	2014.02.05 V00.12 Added log file
 */
 
 #include "dsgwd_pi.h"
@@ -59,6 +63,7 @@ unsigned char	PacketIdSave[2];
 
 char	PTT_On;
 char	COS_On;
+
 void CloseSocket()
 {
         if (dstSocket != 0){
@@ -75,6 +80,11 @@ void CloseSocket()
 	mq_unlink ("/dstar_inet");
 
 //	pthread_join (usb_ID, NULL);
+
+        logfile = fopen (LOGFILE, "a");
+	now = time(NULL);
+        fprintf (logfile, "%24.24s dsgwd_pi %s end\n", ctime(&now), VERSION);
+        fclose(logfile);
         exit(0);
 }
 
@@ -272,9 +282,8 @@ int main(int argc, const char **argv)
 
 	// IP アドレス，ソケット，sockaddr_in 構造体
 	struct sockaddr_in dstAddr;
-
-	//struct sockaddr_in addr;
  	struct	hostent *hp;
+
   	char	buf[128];
 	int	numrcv;
 	int	status;
@@ -285,15 +294,25 @@ int main(int argc, const char **argv)
         signal(SIGINT,CloseSocket);
         signal(SIGTERM,CloseSocket);
 
+
+	logfile = fopen (LOGFILE, "a");
+	now = time(NULL);
+	fprintf (logfile, "%24.24s dsgwd_pi %s start\n", ctime(&now), VERSION);
+	fclose(logfile);
+
 	srand ((unsigned) time (NULL));
 
 	/* PID の書き出し　/var/run/dsgwd_pi.pid  */
 	PidFile = fopen ("/var/run/dsgwd_pi.pid","w");
 	if (PidFile == NULL)
 	{
-		printf ("must run on supper user\n");
+        	logfile = fopen (LOGFILE, "a");
+        	now = time(NULL);
+        	fprintf (logfile, "%24.24s Must run on supper user\n");
+        	fclose(logfile);
 		exit(-1);
 	}
+
 	fprintf (PidFile, "%d\n",(int)getpid());
 	fclose (PidFile);
 
@@ -325,7 +344,10 @@ int main(int argc, const char **argv)
 		cmdin = open ("/tmp/dsgwd_pi-cmdin", O_NONBLOCK | O_RDONLY);
 		if (cmdin < 0)
 		{
-			printf ("ERROR FIFO file not open /tmp/dsgwd_pi-cmdin\n");
+        		logfile = fopen (LOGFILE, "a");
+        		now = time(NULL);
+			fprintf (logfile, "%24.24s ERROR FIFO file not open /tmp/dsgwd_pi-cmdin\n", ctime(&now));
+			fclose (logfile);
 			cmdin = 0;
 		}
 	}
@@ -357,7 +379,10 @@ int main(int argc, const char **argv)
 	status = pthread_create (&usb_ID, NULL, node_adapter, (void *)NULL);
 	if (status)
 	{
-		printf ("pthread error %s\n", strerror(status));
+        	logfile = fopen (LOGFILE, "a");
+        	now = time(NULL);
+		fprintf (logfile, "%24.24s pthread error %s\n", ctime(&now), strerror(status));
+		fclose (logfile);
 		exit(-1);
 	}
 
@@ -374,19 +399,22 @@ int main(int argc, const char **argv)
 	//接続
 	if (connect(dstSocket, (struct sockaddr *)&dstAddr, 
 			sizeof(dstAddr)) < 0){
-		printf("Does not connect to '%s'.\n",TrustDomainName);
+        	logfile = fopen (LOGFILE, "a");
+        	now = time(NULL);
+		fprintf(logfile, "%24.24s Does not connect to '%s'.\n",ctime(&now),TrustDomainName);
+		fclose (logfile);
 		CloseSocket();	
 	}
-
-	printf("Connect to '%s'.\n", TrustDomainName);
+        logfile = fopen (LOGFILE, "a");
+        now = time(NULL);
+	fprintf(logfile, "%24.24s Connect to '%s'.\n", ctime(&now), TrustDomainName);
+	fclose (logfile);
 
 	//コールサイン入力のプロンプト
 	memset (buf, 0x20, 14); 
 	while (memcmp (buf,"Repeater Call:", 14) != 0)
 	{
 		numrcv = recv(dstSocket, buf, 64, 0);
-		buf[numrcv] = 0x00;
-		printf("%s\n",buf);
 	}
 
 	//コールサインの送信
@@ -401,8 +429,6 @@ int main(int argc, const char **argv)
 	while (memcmp (buf, "Password:", 9) != 0)
 	{
         	numrcv = recv(dstSocket, buf,  128, 0);
-        	buf[numrcv] = 0x00;
-		printf ("%s\n",buf);
 	}
 
         //パスワードの送信
@@ -411,14 +437,12 @@ int main(int argc, const char **argv)
         //ポート番号入力のプロンプト
 	memset (buf, 0x20, 12);
 	numrcv = recv (dstSocket, buf, 128, 0);
-        if (memcmp (buf, "Port Number:", 12) == 0)
+        if (!memcmp (buf, "Port Number:", 12) == 0)
 	{
-       	 	buf[numrcv] = 0x00;
-        	printf("%s\n",buf);
-	}
-	else
-	{
-		printf ("Invalid CallSign or Password\n");
+        	logfile = fopen (LOGFILE, "a");
+        	now = time(NULL);
+		fprintf (logfile, "%24.24s Invalid CallSign or Password\n", ctime(&now));
+		fclose (logfile);
 		CloseSocket();
 	}
 		
@@ -443,6 +467,7 @@ int main(int argc, const char **argv)
 	if (width < udpSocket) width = udpSocket;
 	if (width < cmdin) width = cmdin;
 	width++;
+
 	while (1){
 		readOk = Mask;
 		if (ConnectWait) FD_CLR(rf_qid, &readOk);
@@ -468,7 +493,10 @@ int main(int argc, const char **argv)
 						FirstHeaderSend = TRUE;
 						AckTimeOut = 0;
 						Connected = TRUE;
-						printf ("Change to Relay Mode\n");
+        					logfile = fopen (LOGFILE, "a");
+        					now = time(NULL);
+						fprintf (logfile, "%24.24s Change to Relay Mode\n", ctime(&now));
+						fclose (logfile);
 					}
 				}
 				if (DVwait)
@@ -512,20 +540,26 @@ int main(int argc, const char **argv)
                         		}
                                         else if (reqConMsg.reqType == Nak)
                                         {
-                                                printf ("Nak %2.2x %8.8s %s %d\n",
+        					logfile = fopen (LOGFILE, "a");
+        					now = time(NULL);
+                                                fprintf (logfile, "%24.24s Nak %2.2x %8.8s %s %d\n", ctime(&now),
                                                         reqConMsg.reqType, reqConMsg.ackConnect.YourCall,
                                                         inet_ntoa (reqConMsg.ackConnect.ip),
                                                         ntohs(reqConMsg.ackConnect.port));
-							respFlags = reqConMsg.ackConnect.RespFlags;
+						fclose (logfile);
+						respFlags = reqConMsg.ackConnect.RespFlags;
                                         }
                         		else if (reqConMsg.reqType == ReqConnect)
                         		{
-                                		printf ("Req %2.2x %2.2x %8.8s %s %d\n", 
+        					logfile = fopen (LOGFILE, "a");
+        					now = time(NULL);
+                                		fprintf (logfile, "%24.24s Req %2.2x %2.2x %8.8s %s %d\n", ctime(&now),
 							reqConMsg.reqType,
 							reqConMsg.reqConnect.protocol, 
 							reqConMsg.reqConnect.YourCall, 
 							inet_ntoa(reqConMsg.reqConnect.ip),
 							ntohs(reqConMsg.reqConnect.port));
+						fclose (logfile);
 						if (PTT_On || COS_On)
 						{
 							NakSendTrust(reqConMsg.reqConnect.Rpt1Call);
@@ -548,12 +582,16 @@ int main(int argc, const char **argv)
 				if(FD_ISSET(cmdin, &readOk))
 				{
                 			read (cmdin, buf, 64);
-                			if (memcmp (buf, "end", 3) == 0)
+                			if (!memcmp (buf, "end", 3))
 					{
 						reqConMsg.reqType = ReqEnd;
         					send (dstSocket, (char *)&reqConMsg, sizeof(reqConMsg), 0);
         					CloseSocket();
 					}
+					else if (!memcmp (buf, "reload_callcheck", 16))
+					{
+						ReloadCallCheckACL();
+					}
 				}
 				break;
 		}
