@@ -3,6 +3,8 @@
 	Date		2014.01.20
 */
 
+#define	VERSION	"V00.12"
+#define	LOGFILE	"/var/log/dsgwd_pi.log"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -216,3 +218,6 @@ struct	packet	dv_frame;
 
 unsigned	int	NodeVendorID;
 unsigned	int	NodeProductID;
+
+FILE	*logfile;
+time_t	now;
